@@ -18,7 +18,7 @@ This product includes software developed by and/or derived from the Access
 Grid Project (http://www.accessgrid.org) to which the U.S. Government retains 
 certain rights."""
 __contact__ = "Philip.Kershaw@stfc.ac.uk"
-__revision__ = '$Id: client.py 7928 2011-08-12 13:16:26Z pjkersha $'
+__revision__ = '$Id: client.py 8286 2013-11-18 16:03:02Z pjkersha $'
 import logging
 log = logging.getLogger(__name__)
 
@@ -539,8 +539,8 @@ TRUSTED_CERTS=1"""
     def _setHostname(self, val):
         """Also sets SSL Certificate verification object property!"""
         if not isinstance(val, basestring):
-            raise TypeError("Expecting string type for hostname "
-                                 "attribute")
+            raise TypeError("Expecting string type for hostname attribute")
+        
         self.__hostname = val
         self.__serverSSLCertVerify.hostname = val
         
@@ -834,16 +834,16 @@ TRUSTED_CERTS=1"""
             if ind < 0:
                 break
                 
-            len = 256*ord(dat[ind+2]) + ord(dat[ind+3])
+            length = 256*ord(dat[ind+2]) + ord(dat[ind+3])
     
             # extract der-format cert, and convert to pem
-            derCert = dat[ind:ind+len+4]
+            derCert = dat[ind:ind+length+4]
             x509Cert = crypto.load_certificate(crypto.FILETYPE_ASN1, derCert)
             pemCert = crypto.dump_certificate(crypto.FILETYPE_PEM, x509Cert)        
             pemCerts.append(pemCert)
     
             # trim cert from data
-            dat = dat[ind + len + 4:]
+            dat = dat[ind + length + 4:]
            
         return pemCerts
 
@@ -884,7 +884,7 @@ TRUSTED_CERTS=1"""
                                           *cls.HOSTKEY_SUBDIRPATH)
                 if os.access(sslKeyFile, os.R_OK):
                     sslCertFile = os.path.join(globusLoc, 
-                                           *cls.HOSTCERT_SUBDIRPATH)
+                                               *cls.HOSTCERT_SUBDIRPATH)
                 else:
                     # Access to the private key is prohibited default to
                     # username/password based authentication             
@@ -917,19 +917,18 @@ TRUSTED_CERTS=1"""
                                      "platform?")
         
         outStr = proxyCert + proxyPriKey + userX509Cert       
-        open(MyProxyClient.DEF_PROXY_FILEPATH, 'w').write(outStr)
+        open(filePath, 'w').write(outStr)
         try:
             # Make sure permissions are set correctly
-            os.chmod(MyProxyClient.DEF_PROXY_FILEPATH, 
-                     MyProxyClient.PROXY_FILE_PERMISSIONS)
-        except Exception, e:
-            # Don't leave the file lying around if couldn't change it's
-            # permissions
-            os.unlink(MyProxyClient.DEF_PROXY_FILEPATH)
+            os.chmod(filePath, MyProxyClient.PROXY_FILE_PERMISSIONS)
             
-            log.error('Unable to set %o permissions for proxy file "%s": %s'% 
-                      (MyProxyClient.PROXY_FILE_PERMISSIONS,
-                       MyProxyClient.DEF_PROXY_FILEPATH, e))
+        except OSError, e:
+            # Don't leave the file lying around if couldn't change its
+            # permissions
+            os.unlink(filePath)
+            
+            log.error('Unable to set %o permissions for proxy file "%s": %s', 
+                      MyProxyClient.PROXY_FILE_PERMISSIONS, filePath, e)
             raise
 
     @classmethod
@@ -946,7 +945,7 @@ TRUSTED_CERTS=1"""
             MyProxyClientConfigError("Error setting proxy file path - invalid "
                                      "platform?")
                
-        proxy = open(MyProxyClient.DEF_PROXY_FILEPATH).read()
+        proxy = open(filePath).read()
         
         # Split certs and key into separate tuple items
         return tuple(['-----BEGIN'+i for i in proxy.split('-----BEGIN')[1:]])
